]> AND Private Git Repository - loba.git/blobdiff - process.h
Logo AND Algorithmique Numérique Distribuée

Private GIT Repository
Add extract.pl.
[loba.git] / process.h
index 68dcd9b71fecc45abc4dbc9f27c51b5e07348c34..b15f98297cc540481516b4fa0bd3052e5a4d57f2 100644 (file)
--- a/process.h
+++ b/process.h
 
 class process {
 public:
 
 class process {
 public:
-    static double get_total_load_init() { return total_load_init; }
-    static double get_total_load_exit() { return total_load_exit; }
+    static double get_total_load_init()    { return total_load_init;    }
+    static double get_total_load_running() { return total_load_running; }
+    static double get_total_load_exit()    { return total_load_exit;    }
 
     process(int argc, char* argv[]);
     virtual ~process();
 
 
     process(int argc, char* argv[]);
     virtual ~process();
 
+    double get_load() const                { return load; }
+
     int run();
 
 protected:
     int run();
 
 protected:
@@ -48,8 +51,9 @@ protected:
                        xbt_log_category_t cat = _XBT_LOGV(default)) const;
 
 private:
                        xbt_log_category_t cat = _XBT_LOGV(default)) const;
 
 private:
-    static double total_load_init; // sum of neighbor loads at init
-    static double total_load_exit; // sum of neighbor loads at exit
+    static double total_load_init; // sum of process loads at init
+    static double total_load_running; // summ of loads while running
+    static double total_load_exit; // sum of process loads at exit
 
     typedef MAP_TEMPLATE<m_host_t, neighbor*> rev_neigh_type;
     neigh_type neigh;           // list of neighbors (do not alter
 
     typedef MAP_TEMPLATE<m_host_t, neighbor*> rev_neigh_type;
     neigh_type neigh;           // list of neighbors (do not alter
@@ -61,8 +65,11 @@ private:
                                 // on ctrl channel
     int data_close_pending;     // number of "close" messages to wait
                                 // on data channel
                                 // on ctrl channel
     int data_close_pending;     // number of "close" messages to wait
                                 // on data channel
+    bool close_received;        // true if we received a "close" message
+    bool finalizing;            // true when finalize() is running
 
 
-    unsigned iter;              // counter of iterations
+    unsigned lb_iter;           // counter of load-balancing iterations
+    unsigned comp_iter;         // counter of computation iterations
 
     double prev_load_broadcast; // used to ensure that we do not send
                                 // a same information messages
 
     double prev_load_broadcast; // used to ensure that we do not send
                                 // a same information messages
@@ -83,11 +90,11 @@ private:
     void send1_bookkeeping(neighbor& nb);
     void send();
 
     void send1_bookkeeping(neighbor& nb);
     void send();
 
-    // Receive procedure: wait (or not) for a message to come.
-    // Returns false if some "close" message was received, returns true
-    // otherwise.
-    enum recv_wait_mode { NO_WAIT = 0, WAIT, WAIT_FOR_CLOSE };
-    bool receive(recv_wait_mode wait);
+    // Returns true if there remains neighbors to listen for
+    bool may_receive() { return ctrl_close_pending || data_close_pending; }
+
+    // Receive procedure: wait (or not) for a message to come
+    void receive(bool wait);
 
     // Finalize sends a "close" message to each neighbor and wait for
     // all of them to answer.
 
     // Finalize sends a "close" message to each neighbor and wait for
     // all of them to answer.